# kurvy

[![PyPI - Version](https://img.shields.io/pypi/v/kurvy.svg)](https://pypi.org/project/kurvy/)

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kurvy.svg)](https://pypi.org/project/kurvy/)

[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/celerygemini/kurvy/blob/main/LICENSE)